package com.fs.watch.service;

import com.fs.watch.domain.WatchDeviceInfo;
import com.fs.watch.domain.vo.WatchDeviceInfoAndUserIdVo;
import com.fs.watch.domain.vo.WatchDeviceInfoVo;
import com.fs.watch.param.WatchDeviceInfoQueryParam;

import java.util.List;
import java.util.Map;

/**
* @author Administrator
* @description 针对表【watch_device_info(设备硬件信息)】的数据库操作Service
* @createDate 2024-10-15 11:06:50
*/
public interface WatchDeviceInfoService{

    int insertDeviceInfo(WatchDeviceInfo data);

    int updateByDeviceNumber(WatchDeviceInfo data);

    int remove(String deviceNums);

    Map<String,Object> getInfo(String deviceNumber);

    /**
     * 查询设备信息
     *
     * @param deviceId 设备信息主键
     * @return 设备信息
     */
    public WatchDeviceInfoVo selectDeviceInfoByDeviceId(Long deviceId);

    /**
     * 修改设备信息
     *
     * @param deviceInfo 设备信息
     * @return 结果
     */
    public int updateDeviceInfo(WatchDeviceInfo deviceInfo);

    /**
     * 查询设备信息列表
     *
     * @param param 设备信息
     * @return 设备信息集合
     */
    public List<WatchDeviceInfoVo> selectDeviceInfoList(WatchDeviceInfoQueryParam param);

    List<WatchDeviceInfoAndUserIdVo> selectByUserExist();

    WatchDeviceInfoVo getByNumber(String deviceId);

    Integer getStatus(String deviceId);

    public int deleteDeviceInfoByDeviceIds(Long[] deviceIds);
}
